==> haskell-network-2.6.3.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network
version: 2.6.3.1
id: network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
key: network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
license: BSD3
maintainer: Kazu Yamamoto, Evan Borden
homepage: https://github.com/haskell/network
synopsis: Low-level networking interface
description:
    This package provides a low-level networking interface.
    .
    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal
hidden-modules: Network.Socket.ByteString.Internal
                Network.Socket.Types Network.Socket.ByteString.IOVec
                Network.Socket.ByteString.Lazy.Posix
                Network.Socket.ByteString.MsgHdr
abi: 313d4599f2fcff6529796da690f3b9cd
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/network-2.6.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/network-2.6.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/network-2.6.3.1
hs-libraries: HSnetwork-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
include-dirs: /usr/lib/ghc-8.0.1/site-local/network-2.6.3.1/include
includes:
    HsNet.h
depends:
    base-4.9.0.0 bytestring-0.10.8.1 unix-2.7.2.0
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro"
haddock-interfaces: /usr/share/doc/haskell-network/html/network.haddock
haddock-html: /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-2.6.3.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network
version: 2.6.3.2
id: network-2.6.3.2-GMjPV5zpIjuBSljTanWiH
key: network-2.6.3.2-GMjPV5zpIjuBSljTanWiH
license: BSD3
maintainer: Kazu Yamamoto, Evan Borden
homepage: https://github.com/haskell/network
synopsis: Low-level networking interface
description:
    This package provides a low-level networking interface.
    .
    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal
hidden-modules: Network.Socket.ByteString.Internal
                Network.Socket.Types Network.Socket.ByteString.IOVec
                Network.Socket.ByteString.Lazy.Posix
                Network.Socket.ByteString.MsgHdr
abi: dc0ba84d0f5b4c59f35d3b0aeff9ec34
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/network-2.6.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/network-2.6.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/network-2.6.3.2
hs-libraries: HSnetwork-2.6.3.2-GMjPV5zpIjuBSljTanWiH
include-dirs: /usr/lib/ghc-8.0.1/site-local/network-2.6.3.2/include
includes:
    HsNet.h
depends:
    base-4.9.0.0 bytestring-0.10.8.1 unix-2.7.2.0
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro"
haddock-interfaces: /usr/share/doc/haskell-network/html/network.haddock
haddock-html: /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
